function [Acp, Fcp, Acn, Fcn]=congr(Y,A,F_r)

% Congruent envelope and instantaneous frequency
% Input:
% Y - decomposed components, A - component envelopes ,
% F_r - component relative frequency
% Output:
% Acp - Positive congruent envelope
% Fcp - Positive congruent frequency
% Acn - Negativecongruent envelope
% Fcn - Negative congruent frequency
% Example:  [Acp, Fcp, Acn, Fcn] = congr(Y,A,F_r);
%
%  2011 Michael Feldman
% For use with the book "HILBERT TRANSFORM APPLICATION
% IN MECHANICAL VIBRATION", John Wiley & Sons, 2011

S=size(Y);
k=S(2);
if k==1, Acp=A(:,1); Fcp=(F_r(:,1)); Acn=-Acp; Fcn=Fcp;
else
    for l=2:k
        [phi_p(:,l), phi_n(:,l)]=coph(Y(:,1),Y(:,l));
        Acp(:,l)=A(:,l).*cos(pi.*phi_p(:,l)/180);
        Fcp(:,l)=A(:,l).*F_r(:,l).*cos(pi.*phi_p(:,l)/180);
        Acn(:,l)=A(:,l).*cos(pi.*phi_n(:,l)/180);
        Fcn(:,l)=A(:,l).*F_r(:,l).*cos(pi.*phi_n(:,l)/180);
    end
    Acp=A(:,1)+sum(Acp')';
    Fcp=(A(:,1).*F_r(:,1)+sum(Fcp')')./Acp;
    Acn=-A(:,1)-sum(Acn')';
    Fcn=-(A(:,1).*F_r(:,1)+sum(Fcn')')./Acn;
end
