function [y, yH]=hilbTurner(x)
%
% Hilbert transform via Turner filter (for very long length data). Described by  
% article: "An Efficient Analytic Signal Generator" by Clay S. Turner.
% MathCAD and MATLAB code, modeling this dual quadrature 
% filters technique, is available for downloading at
% http://www.signalprocessingsociety.org/uploads/Publications/SPM/AnalyticSignalGenerator.zip
%
% [A_of_k, B_of_k] = QuadFilterCoeffs_Turner(w1, w2, a, N);
%
% Computes the coefficients for the quadrature filters
% described by article: "An Efficient Analytic Signal Generator"
% by Clay S. Turner.
%
%    w1: beginning frequency of filters' passband (-3dB point).
%       "w1" must be in the range of 0 -to- 0.5. 
%    w2: end frequency of filters' passband (-3dB point).
%       "w2" must be in the range of 0 -to- 0.5, and greater than w1. 
%    a: half the filters' desired transition-region width.
%       "a" must be in the range of 0 -to- 0.5. 
%    N: number of filter taps.
%    A_of_k: the computed in-phase filter's coefficients.
%    B_of_k: the computed quadrature-phase filter's coefficients.
%
% Code by Richard (Rick) Lyons.  Sept. 2008.
% Use this code however you wish, but please do not change 
% the above comment lines. 
%
% N=512; 
 w1=0.003; % a=0.003; w2=0.497;
% [A_of_k, B_of_k] = QuadFilterCoeffs_Turner_plots(w1, w2, a, N);
%
x=x(:);
DC=ilpf(x,2*w1); 
load hilbTurner.mat
y = filter(A_of_k, 1, x) + DC;
yH = filter(B_of_k, 1, x);

