function [A,F,phi]=inst(x,Fs)
% Instantaneous characteristics of the signal x.
% Fs - Sampling frequency [Hz]
% A - Envelope
% F - Instantaneous frequency [Hz]
% phi - Instanatneous phase
% The initial signal can be presented through 
% instantaneous characterisitics as  x=A.*cos(phi); 
%
% Example
% [A,F,phi]=inst(x,Fs);
%
%  2011 Michael Feldman   
% For use with the book "HILBERT TRANSFORM APPLICATION 
% IN MECHANICAL VIBRATION", John Wiley & Sons, 2011
%

% IF via symbolic difference between two arctangents 
x=x(:);
xH=hilbfir(x);      % Hilbert transform via FIR filter
% xH=hilbfft(x); 
%[x,xH]  = hilbturner(x); % Hilbert transform via Turner filter
A2=(xH.^2+x.^2);  A=sqrt(A2); % Envelope
Xc=x+i*xH;          % Analytic signal
Xd = Xc(2:length(x)).*conj(Xc(1:length(x)-1));
omega1=angle(Xd);
om1=0.5*([0; omega1]+[omega1; 0]);
F=Fs*om1/2/pi;        % Instantaneous frequency, [Hz]
ph1=atan2(xH,x);    
phi=unwrap(ph1);      % Instantaneous phase


