function plfor(y,A,f0,h,Ayd,f,m)
% Hilbert transform identification presentation 
% y  -  Forced vibration solution 
% A  -  Envelope 
% f0 -  Natural frequency
% 
% Example:  plfor(z,A,f0,h,Ayd)
% 
%  2011 Michael Feldman   
% For use with the book "HILBERT TRANSFORM APPLICATION 
% IN MECHANICAL VIBRATION", John Wiley & Sons, 2011     
%

close all;
pp=(232:length(y)-232);

figure(1);set(1,'Position',[50 409 941 288]);
subplot(211);
plot(pp,y(pp),'k',pp,A(pp),'r','LineWidth',2); 
axis([pp(1) pp(length(pp)) -1.1*max(A(pp)) 1.1*max(A(pp))]);
title('Signal and Envelope');
ylabel('Amplitude');
grid on; 

subplot(212);
plot(pp,f0(pp),'lineWidth',2);hold on
plot(pp,f(pp),'--k','lineWidth',2);
axis([pp(1) pp(length(pp)) 0.99*min(f(pp)) 1.01*max(f(pp))]);
title('Forced & Natural Frequencies');
xlabel('Time,  s');ylabel('Frequency,  Hz')
grid on;

% FRF calculation
figure(2);set(2,'Position',[50 42 452 284]);

ff1=sqrt(abs(4.*pi^2.*f0.^2-2*h.^2+4.*pi.*f0.*h.*...
sqrt( (max(A))^2./(A.^2 +eps) -1+...
(h).^2./(4.*pi^2.*f0.^2+eps))))/2/pi ;

ffi=4.*pi^2.*f0.^2-2*h.^2-4.*pi.*f0.*h.*...
sqrt( (max(A))^2./(A.^2 +eps) -1+...
(h).^2./(4.*pi^2.*f0.^2+eps));

ind_ffi=find(ffi>0);

ff2=zeros(length(y),1);
ff2(ind_ffi)=sqrt(ffi(ind_ffi))./2/pi;

FRF=[ff1 ff2];       % Freqyency Response Function

subplot(121);
plot(FRF(pp,:),A(pp),'r--','LineWidth',1);hold on
plot(f0(pp),A(pp),'b','LineWidth',2);
axis([min(min(FRF(pp,:))) max(max(FRF(pp,:))) 0 1.1*max(A(pp))]);
xlabel('Frequecy,  Hz');ylabel('Amplitude');
title(['Back-Bone, FRF;    mass = ' num2str(m)]);
grid on;
subplot(122);
plot(h(pp),A(pp),'m.','MarkerSize',4);  
axis([0 1.5*max(h(pp)) 0 1.1*max(A(pp))]);
xlabel('Damping coefficient,  1/s');ylabel('Amplitude');
title(['Damping curve']);
grid on;

% Static force calculation
figure(3);set(3,'Position',[509 42 482 284]);

iel=find(y > 0.98*A  & y < 1.02*A); 
yH  = hilbfir(y);
ifr=find(yH > 0.97*A & y < 1.03*A);
iel(iel<pp(1)| iel>=pp(length(pp)))=[];
ifr(ifr<pp(1)| ifr>=pp(length(pp)))=[];
fofr=2*m*h(ifr).*Ayd(ifr);         % Friction Force 
foel=4*m*(pi*f0(iel)).^2.*A(iel);  % Elastic force

subplot(121);
plot([-A(iel) A(iel)],[-foel foel],'k.'); hold on
plot([-A(iel) A(iel)],[-foel foel],'b');
title(['Elastic Static Force;     mass = ' num2str(m)]);
ylabel('Elastic Force'); xlabel('Displacement')
grid on; 
hold off

subplot(122);
plot([-Ayd(ifr) Ayd(ifr)],[-fofr fofr],'k.'); hold on
plot([-Ayd(ifr) Ayd(ifr)],[-fofr fofr],'m'); 
title('Friction Force');
xlabel('Velocity');ylabel('Friction Force')
grid on;
hold off;
